==> php54-owncloud-8.0.4.tgz: share/owncloud/apps/files/l10n/ar.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "خطأ غير معروف. ",
    "Could not move %s - File with this name already exists" : "فشل في نقل الملف %s - يوجد ملف بنفس هذا الاسم",
    "Could not move %s" : "فشل في نقل %s",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "اسم غير صحيح , الرموز  '\\', '/', '<', '>', ':', '\"', '|', '?' و \"*\" غير مسموح استخدامها",
    "Unable to set upload directory." : "غير قادر على تحميل المجلد",
    "Invalid Token" : "علامة غير صالحة",
    "No file was uploaded. Unknown error" : "لم يتم رفع أي ملف , خطأ غير معروف",
    "There is no error, the file uploaded with success" : "تم ترفيع الملفات بنجاح.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "حجم الملف المرفوع تجاوز قيمة  upload_max_filesize الموجودة في ملف php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "The uploaded file was only partially uploaded" : "تم ترفيع جزء من الملفات الذي تريد ترفيعها فقط",
    "No file was uploaded" : "لم يتم ترفيع أي من الملفات",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Failed to write to disk" : "خطأ في الكتابة على القرص الصلب",
    "Not enough storage available" : "لا يوجد مساحة تخزينية كافية",
    "Upload failed. Could not find uploaded file" : "*فشلت علمية الرفع. تعذر إيجاد الملف الذي تم رفعه.\n*فشلت علمية التحميل. تعذر إيجاد الملف الذي تم تحميله.",
    "Upload failed. Could not get file info." : "فشلت عملية الرفع. تعذر الحصول على معلومات الملف.",
    "Invalid directory." : "مسار غير صحيح.",
    "Files" : "الملفات",
    "Favorites" : "المفضلة ",
    "Home" : "البيت",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
    "Upload cancelled." : "تم إلغاء عملية رفع الملفات .",
    "Could not get result from server." : "تعذر الحصول على نتيجة من الخادم",
    "File upload is in progress. Leaving the page now will cancel the upload." : "عملية رفع الملفات قيد التنفيذ. اغلاق الصفحة سوف يلغي عملية رفع الملفات.",
    "{new_name} already exists" : "{new_name} موجود مسبقا",
    "Rename" : "إعادة تسميه",
    "Delete" : "إلغاء",
    "Unshare" : "إلغاء المشاركة",
    "Download" : "تحميل",
    "Pending" : "قيد الانتظار",
    "Error moving file" : "حدث خطأ أثناء نقل الملف",
    "Error" : "خطأ",
    "Name" : "اسم",
    "Size" : "حجم",
    "Modified" : "معدل",
    "_%n folder_::_%n folders_" : ["لا يوجد مجلدات %n","1 مجلد %n","2 مجلد %n","عدد قليل من مجلدات %n","عدد كبير من مجلدات %n","مجلدات %n"],
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","ملف %n","2 ملف %n","قليل من ملفات %n","الكثير من ملفات %n"," ملفات %n"],
    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","يتم تحميل ملفات %n"],
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكم تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Your storage is almost full ({usedSpacePercent}%)" : "مساحتك التخزينية امتلأت تقريبا ",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "تم تمكين تشفير البرامج لكن لم يتم تهيئة المفاتيح لذا يرجى تسجيل الخروج ثم تسجيل الدخول مرة آخرى.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "المفتاح الخاص بتشفير التطبيقات غير صالح. يرجى تحديث كلمة السر الخاصة بالمفتاح الخاص من الإعدادت الشخصية حتى تتمكن من الوصول للملفات المشفرة.",
    "Encryption was disabled but your files are still encrypted. Please go to your personal settings to decrypt your files." : "تم تعطيل التشفير لكن ملفاتك لا تزال مشفرة. فضلا اذهب إلى الإعدادات الشخصية لإزالة التشفير عن ملفاتك.",
    "_matches '{filter}'_::_match '{filter}'_" : ["","","","","",""],
    "{dirs} and {files}" : "{dirs} و {files}",
    "Favorite" : "المفضلة",
    "%s could not be renamed" : "%s  لا يمكن إعادة تسميته. ",
    "File handling" : "التعامل مع الملف",
    "Maximum upload size" : "الحد الأقصى لحجم الملفات التي يمكن رفعها",
    "max. possible: " : "الحد الأقصى المسموح به",
    "Save" : "حفظ",
    "Settings" : "إعدادات",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "استخدم هذا العنوان لـ  <a href=\"%s\" target=\"_blank\">الدخول الى ملفاتك عن طريق WebDAV</a>",
    "New" : "جديد",
    "Text file" : "ملف",
    "New folder" : "مجلد جديد",
    "Folder" : "مجلد",
    "From link" : "من رابط",
    "Upload" : "رفع",
    "Cancel upload" : "إلغاء الرفع",
    "Upload too large" : "حجم الترفيع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
    "Files are being scanned, please wait." : "يرجى الانتظار , جاري فحص الملفات ."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files/l10n/ar.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "خطأ غير معروف. ",
    "Could not move %s - File with this name already exists" : "فشل في نقل الملف %s - يوجد ملف بنفس هذا الاسم",
    "Could not move %s" : "فشل في نقل %s",
    "Unable to set upload directory." : "غير قادر على تحميل المجلد",
    "Invalid Token" : "علامة غير صالحة",
    "No file was uploaded. Unknown error" : "لم يتم رفع أي ملف , خطأ غير معروف",
    "There is no error, the file uploaded with success" : "تم ترفيع الملفات بنجاح.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "حجم الملف المرفوع تجاوز قيمة  upload_max_filesize الموجودة في ملف php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "The uploaded file was only partially uploaded" : "تم ترفيع جزء من الملفات الذي تريد ترفيعها فقط",
    "No file was uploaded" : "لم يتم ترفيع أي من الملفات",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Failed to write to disk" : "خطأ في الكتابة على القرص الصلب",
    "Not enough storage available" : "لا يوجد مساحة تخزينية كافية",
    "Upload failed. Could not find uploaded file" : "*فشلت علمية الرفع. تعذر إيجاد الملف الذي تم رفعه.\n*فشلت علمية التحميل. تعذر إيجاد الملف الذي تم تحميله.",
    "Upload failed. Could not get file info." : "فشلت عملية الرفع. تعذر الحصول على معلومات الملف.",
    "Invalid directory." : "مسار غير صحيح.",
    "Files" : "الملفات",
    "Favorites" : "المفضلة ",
    "Home" : "البيت",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
    "Upload cancelled." : "تم إلغاء عملية رفع الملفات .",
    "Could not get result from server." : "تعذر الحصول على نتيجة من الخادم",
    "File upload is in progress. Leaving the page now will cancel the upload." : "عملية رفع الملفات قيد التنفيذ. اغلاق الصفحة سوف يلغي عملية رفع الملفات.",
    "{new_name} already exists" : "{new_name} موجود مسبقا",
    "Rename" : "إعادة تسميه",
    "Delete" : "إلغاء",
    "Unshare" : "إلغاء المشاركة",
    "Download" : "تحميل",
    "Pending" : "قيد الانتظار",
    "Error moving file" : "حدث خطأ أثناء نقل الملف",
    "Error" : "خطأ",
    "Name" : "اسم",
    "Size" : "حجم",
    "Modified" : "معدل",
    "_%n folder_::_%n folders_" : ["لا يوجد مجلدات %n","1 مجلد %n","2 مجلد %n","عدد قليل من مجلدات %n","عدد كبير من مجلدات %n","مجلدات %n"],
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","ملف %n","2 ملف %n","قليل من ملفات %n","الكثير من ملفات %n"," ملفات %n"],
    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","يتم تحميل ملفات %n"],
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكم تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Your storage is almost full ({usedSpacePercent}%)" : "مساحتك التخزينية امتلأت تقريبا ",
    "{dirs} and {files}" : "{dirs} و {files}",
    "Favorite" : "المفضلة",
    "A new file or folder has been <strong>created</strong>" : "تم <strong>  إنشاء</strong> ملف جديد أو مجلد ",
    "A file or folder has been <strong>changed</strong>" : "تم  <strong> تغيير</strong> ملف أو مجلد",
    "A file or folder has been <strong>deleted</strong>" : "تم <strong>حذف </strong> ملف أو مجلد",
    "A file or folder has been <strong>restored</strong>" : "تم <strong> استعادة </strong> ملف أو مجلد",
    "You created %1$s" : "لقد أنشأت %1$s",
    "%2$s created %1$s" : "%2$s أنشأ %1$s",
    "%1$s was created in a public folder" : "تم إنشاء %1$s في مجلد عام",
    "You changed %1$s" : "لقد غيرت %1$s",
    "%2$s changed %1$s" : "%2$s غير %1$s",
    "You deleted %1$s" : "حذفت %1$s",
    "%2$s deleted %1$s" : "%2$s حذف %1$s",
    "You restored %1$s" : "لقد قمت باستعادة %1$s",
    "%2$s restored %1$s" : "%2$s مستعاد %1$s",
    "%s could not be renamed" : "%s  لا يمكن إعادة تسميته. ",
    "File handling" : "التعامل مع الملف",
    "Maximum upload size" : "الحد الأقصى لحجم الملفات التي يمكن رفعها",
    "max. possible: " : "الحد الأقصى المسموح به",
    "Save" : "حفظ",
    "Settings" : "إعدادات",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "استخدم هذا العنوان لـ  <a href=\"%s\" target=\"_blank\">الدخول الى ملفاتك عن طريق WebDAV</a>",
    "New" : "جديد",
    "Text file" : "ملف",
    "New folder" : "مجلد جديد",
    "Folder" : "مجلد",
    "Upload" : "رفع",
    "Cancel upload" : "إلغاء الرفع",
    "Upload too large" : "حجم الترفيع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
    "Files are being scanned, please wait." : "يرجى الانتظار , جاري فحص الملفات ."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
